@@ -1,8 +1,14 @@
 from code_preset import ExistingCode
 
+
 class CodeBuilder:
 
-    def __init__(self, body_commands, script_dirs, funcs, imports, type):
+    def __init__(self, body_commands: list, script_dirs: list, funcs: list, imports: list, type: str):
+        '''
+        The CodeBuilder class is used for generating the final python file for the Linux menus. All of the parameters are generated in another section of code.
+
+        All the configuration is done beforehand, most of the methods work automatically.
+        '''
         self.body_commands = body_commands
         self.script_dirs = list(set(script_dirs))
         self.funcs = funcs
@@ -10,15 +16,26 @@ class CodeBuilder:
         self.type = type.upper()
 
     def build_script_dirs(self):
+        '''
+        Creates the header of necessary path configurations.
+
+        Adds all the 'sys.path.appends' in order to immport the classes and functions.
+        '''
         compiled_dirs = [f'sys.path.append("{x}")' for x in self.script_dirs]
         return '\n'.join(compiled_dirs)
 
     def build_imports(self):
+        '''
+        Creates the header of necessary imports.
+
+        '''
         compiled_imports = [f'import {x}' for x in self.imports]
         return '\n'.join(compiled_imports)
 
-
     def compile(self):
+        '''
+        Creates the code file.
+        '''
         code_head = ExistingCode.CODE_HEAD.value
         script_dirs_code = self.build_script_dirs()
         imports_code = self.build_imports()
@@ -29,7 +46,6 @@ class CodeBuilder:
             class_type = ExistingCode.BACKGROUND_ITEMS.value
         class_body = '\n'.join(map(lambda x: '\t\t' + x, self.body_commands))
 
-
         code_skeleton = '''
 {}
 {}
